pub struct DeleteUser {}Trait Implementations
Sourceimpl ArrangeAccounts for DeleteUser
impl ArrangeAccounts for DeleteUser
type ArrangedAccounts = DeleteUserInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for DeleteUser
impl BorshDeserialize for DeleteUser
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for DeleteUser
impl CarbonDeserialize for DeleteUser
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for DeleteUser
impl Clone for DeleteUser
Sourcefn clone(&self) -> DeleteUser
fn clone(&self) -> DeleteUser
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteUser
impl Debug for DeleteUser
Sourceimpl<'de> Deserialize<'de> for DeleteUser
impl<'de> Deserialize<'de> for DeleteUser
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for DeleteUser
impl Hash for DeleteUser
Sourceimpl PartialEq for DeleteUser
impl PartialEq for DeleteUser
Sourceimpl Serialize for DeleteUser
impl Serialize for DeleteUser
impl Eq for DeleteUser
impl StructuralPartialEq for DeleteUser