pub struct InitializeProtectedMakerModeConfig {
pub max_users: u32,
}Fields
max_users: u32Trait Implementations
Sourceimpl ArrangeAccounts for InitializeProtectedMakerModeConfig
impl ArrangeAccounts for InitializeProtectedMakerModeConfig
type ArrangedAccounts = InitializeProtectedMakerModeConfigInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for InitializeProtectedMakerModeConfigwhere
u32: BorshDeserialize,
impl BorshDeserialize for InitializeProtectedMakerModeConfigwhere
u32: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for InitializeProtectedMakerModeConfig
impl CarbonDeserialize for InitializeProtectedMakerModeConfig
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for InitializeProtectedMakerModeConfig
impl Clone for InitializeProtectedMakerModeConfig
Sourcefn clone(&self) -> InitializeProtectedMakerModeConfig
fn clone(&self) -> InitializeProtectedMakerModeConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for InitializeProtectedMakerModeConfig
impl<'de> Deserialize<'de> for InitializeProtectedMakerModeConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for InitializeProtectedMakerModeConfig
impl PartialEq for InitializeProtectedMakerModeConfig
Sourcefn eq(&self, other: &InitializeProtectedMakerModeConfig) -> bool
fn eq(&self, other: &InitializeProtectedMakerModeConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InitializeProtectedMakerModeConfig
impl StructuralPartialEq for InitializeProtectedMakerModeConfig