pub struct InitializeSignedMsgUserOrders {
pub num_orders: u16,
}Fields
num_orders: u16Trait Implementations
Sourceimpl ArrangeAccounts for InitializeSignedMsgUserOrders
impl ArrangeAccounts for InitializeSignedMsgUserOrders
type ArrangedAccounts = InitializeSignedMsgUserOrdersInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for InitializeSignedMsgUserOrderswhere
u16: BorshDeserialize,
impl BorshDeserialize for InitializeSignedMsgUserOrderswhere
u16: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for InitializeSignedMsgUserOrders
impl CarbonDeserialize for InitializeSignedMsgUserOrders
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for InitializeSignedMsgUserOrders
impl Clone for InitializeSignedMsgUserOrders
Sourcefn clone(&self) -> InitializeSignedMsgUserOrders
fn clone(&self) -> InitializeSignedMsgUserOrders
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for InitializeSignedMsgUserOrders
impl<'de> Deserialize<'de> for InitializeSignedMsgUserOrders
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for InitializeSignedMsgUserOrders
impl Hash for InitializeSignedMsgUserOrders
Sourceimpl PartialEq for InitializeSignedMsgUserOrders
impl PartialEq for InitializeSignedMsgUserOrders
Sourcefn eq(&self, other: &InitializeSignedMsgUserOrders) -> bool
fn eq(&self, other: &InitializeSignedMsgUserOrders) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InitializeSignedMsgUserOrders
impl StructuralPartialEq for InitializeSignedMsgUserOrders