pub struct ModifyOrder {
pub order_id: Option<u32>,
pub modify_order_params: ModifyOrderParams,
}Fields
order_id: Option<u32>modify_order_params: ModifyOrderParamsTrait Implementations
Sourceimpl ArrangeAccounts for ModifyOrder
impl ArrangeAccounts for ModifyOrder
type ArrangedAccounts = ModifyOrderInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for ModifyOrder
impl BorshDeserialize for ModifyOrder
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for ModifyOrder
impl CarbonDeserialize for ModifyOrder
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for ModifyOrder
impl Clone for ModifyOrder
Sourcefn clone(&self) -> ModifyOrder
fn clone(&self) -> ModifyOrder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModifyOrder
impl Debug for ModifyOrder
Sourceimpl<'de> Deserialize<'de> for ModifyOrder
impl<'de> Deserialize<'de> for ModifyOrder
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ModifyOrder
impl Hash for ModifyOrder
Sourceimpl PartialEq for ModifyOrder
impl PartialEq for ModifyOrder
Sourceimpl Serialize for ModifyOrder
impl Serialize for ModifyOrder
impl Eq for ModifyOrder
impl StructuralPartialEq for ModifyOrder