pub struct UpdateAdmin {
pub admin: Pubkey,
}Fields
admin: PubkeyTrait Implementations
Sourceimpl ArrangeAccounts for UpdateAdmin
impl ArrangeAccounts for UpdateAdmin
type ArrangedAccounts = UpdateAdminInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for UpdateAdminwhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for UpdateAdminwhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for UpdateAdmin
impl CarbonDeserialize for UpdateAdmin
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for UpdateAdmin
impl Clone for UpdateAdmin
Sourcefn clone(&self) -> UpdateAdmin
fn clone(&self) -> UpdateAdmin
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateAdmin
impl Debug for UpdateAdmin
Sourceimpl<'de> Deserialize<'de> for UpdateAdmin
impl<'de> Deserialize<'de> for UpdateAdmin
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for UpdateAdmin
impl Hash for UpdateAdmin
Sourceimpl PartialEq for UpdateAdmin
impl PartialEq for UpdateAdmin
Sourceimpl Serialize for UpdateAdmin
impl Serialize for UpdateAdmin
impl Eq for UpdateAdmin
impl StructuralPartialEq for UpdateAdmin