pub struct UpdateProtectedMakerModeConfig {
pub max_users: u32,
pub reduce_only: bool,
}Fields
max_users: u32reduce_only: boolTrait Implementations
Sourceimpl ArrangeAccounts for UpdateProtectedMakerModeConfig
impl ArrangeAccounts for UpdateProtectedMakerModeConfig
type ArrangedAccounts = UpdateProtectedMakerModeConfigInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for UpdateProtectedMakerModeConfig
impl BorshDeserialize for UpdateProtectedMakerModeConfig
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for UpdateProtectedMakerModeConfig
impl CarbonDeserialize for UpdateProtectedMakerModeConfig
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for UpdateProtectedMakerModeConfig
impl Clone for UpdateProtectedMakerModeConfig
Sourcefn clone(&self) -> UpdateProtectedMakerModeConfig
fn clone(&self) -> UpdateProtectedMakerModeConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for UpdateProtectedMakerModeConfig
impl<'de> Deserialize<'de> for UpdateProtectedMakerModeConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UpdateProtectedMakerModeConfig
impl PartialEq for UpdateProtectedMakerModeConfig
Sourcefn eq(&self, other: &UpdateProtectedMakerModeConfig) -> bool
fn eq(&self, other: &UpdateProtectedMakerModeConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateProtectedMakerModeConfig
impl StructuralPartialEq for UpdateProtectedMakerModeConfig