pub struct UpdatePythPullOracle {
pub feed_id: [u8; 32],
pub params: Vec<u8>,
}Fields
feed_id: [u8; 32]params: Vec<u8>Trait Implementations
Sourceimpl ArrangeAccounts for UpdatePythPullOracle
impl ArrangeAccounts for UpdatePythPullOracle
type ArrangedAccounts = UpdatePythPullOracleInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for UpdatePythPullOracle
impl BorshDeserialize for UpdatePythPullOracle
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for UpdatePythPullOracle
impl CarbonDeserialize for UpdatePythPullOracle
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for UpdatePythPullOracle
impl Clone for UpdatePythPullOracle
Sourcefn clone(&self) -> UpdatePythPullOracle
fn clone(&self) -> UpdatePythPullOracle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdatePythPullOracle
impl Debug for UpdatePythPullOracle
Sourceimpl<'de> Deserialize<'de> for UpdatePythPullOracle
impl<'de> Deserialize<'de> for UpdatePythPullOracle
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for UpdatePythPullOracle
impl Hash for UpdatePythPullOracle
Sourceimpl PartialEq for UpdatePythPullOracle
impl PartialEq for UpdatePythPullOracle
Sourceimpl Serialize for UpdatePythPullOracle
impl Serialize for UpdatePythPullOracle
impl Eq for UpdatePythPullOracle
impl StructuralPartialEq for UpdatePythPullOracle