pub struct UpdateStateMaxInitializeUserFee {
pub max_initialize_user_fee: u16,
}Fields
max_initialize_user_fee: u16Trait Implementations
Sourceimpl ArrangeAccounts for UpdateStateMaxInitializeUserFee
impl ArrangeAccounts for UpdateStateMaxInitializeUserFee
type ArrangedAccounts = UpdateStateMaxInitializeUserFeeInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for UpdateStateMaxInitializeUserFeewhere
u16: BorshDeserialize,
impl BorshDeserialize for UpdateStateMaxInitializeUserFeewhere
u16: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for UpdateStateMaxInitializeUserFee
impl CarbonDeserialize for UpdateStateMaxInitializeUserFee
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for UpdateStateMaxInitializeUserFee
impl Clone for UpdateStateMaxInitializeUserFee
Sourcefn clone(&self) -> UpdateStateMaxInitializeUserFee
fn clone(&self) -> UpdateStateMaxInitializeUserFee
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for UpdateStateMaxInitializeUserFee
impl<'de> Deserialize<'de> for UpdateStateMaxInitializeUserFee
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UpdateStateMaxInitializeUserFee
impl PartialEq for UpdateStateMaxInitializeUserFee
Sourcefn eq(&self, other: &UpdateStateMaxInitializeUserFee) -> bool
fn eq(&self, other: &UpdateStateMaxInitializeUserFee) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for UpdateStateMaxInitializeUserFee
impl StructuralPartialEq for UpdateStateMaxInitializeUserFee