pub struct UpdateUserDelegate {
pub sub_account_id: u16,
pub delegate: Pubkey,
}Fields
sub_account_id: u16delegate: PubkeyTrait Implementations
Sourceimpl ArrangeAccounts for UpdateUserDelegate
impl ArrangeAccounts for UpdateUserDelegate
type ArrangedAccounts = UpdateUserDelegateInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for UpdateUserDelegate
impl BorshDeserialize for UpdateUserDelegate
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for UpdateUserDelegate
impl CarbonDeserialize for UpdateUserDelegate
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for UpdateUserDelegate
impl Clone for UpdateUserDelegate
Sourcefn clone(&self) -> UpdateUserDelegate
fn clone(&self) -> UpdateUserDelegate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateUserDelegate
impl Debug for UpdateUserDelegate
Sourceimpl<'de> Deserialize<'de> for UpdateUserDelegate
impl<'de> Deserialize<'de> for UpdateUserDelegate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for UpdateUserDelegate
impl Hash for UpdateUserDelegate
Sourceimpl PartialEq for UpdateUserDelegate
impl PartialEq for UpdateUserDelegate
Sourceimpl Serialize for UpdateUserDelegate
impl Serialize for UpdateUserDelegate
impl Eq for UpdateUserDelegate
impl StructuralPartialEq for UpdateUserDelegate